@@ -4,9 +4,11 @@ import os
 
 import zope.component
 
+from certbot import compat
 from certbot import errors
 from certbot import interfaces
 from certbot import util
+
 from certbot.display import util as display_util
 
 logger = logging.getLogger(__name__)
@@ -33,7 +35,8 @@ def get_email(invalid=False, optional=True):
     unsafe_suggestion = ("\n\nIf you really want to skip this, you can run "
                          "the client with --register-unsafely-without-email "
                          "but make sure you then backup your account key from "
-                         "/etc/letsencrypt/accounts\n\n")
+                         "{0}\n\n".format(os.path.join(
+                             compat.get_default_folder('config'), 'accounts')))
     if optional:
         if invalid:
             msg += unsafe_suggestion
