@@ -9,18 +9,19 @@ logger = logging.getLogger(__name__)
 def get_prefixes(path):
     """Retrieves all possible path prefixes of a path, in descending order
     of length. For instance,
-        /a/b/c/ => ['/a/b/c/', '/a/b/c', '/a/b', '/a', '/']
+        (linux) /a/b/c returns ['/a/b/c', '/a/b', '/a', '/']
+        (windows) C:\\a\\b\\c returns ['C:\\a\\b\\c', 'C:\\a\\b', 'C:\\a', 'C:']
     :param str path: the path to break into prefixes
 
     :returns: all possible path prefixes of given path in descending order
     :rtype: `list` of `str`
     """
-    prefix = path
+    prefix = os.path.normpath(path)
     prefixes = []
     while len(prefix) > 0:
         prefixes.append(prefix)
         prefix, _ = os.path.split(prefix)
-        # break once we hit '/'
+        # break once we hit the root path
         if prefix == prefixes[-1]:
             break
     return prefixes
@@ -51,6 +52,6 @@ def path_surgery(cmd):
         return True
     else:
         expanded = " expanded" if any(added) else ""
-        logger.warning("Failed to find executable %s in%s PATH: %s", cmd,
-                       expanded, path)
+        logger.debug("Failed to find executable %s in%s PATH: %s", cmd,
+                     expanded, path)
         return False
