@@ -10,6 +10,7 @@ import mock
 from acme.magic_typing import Callable, Dict, Union
 # pylint: enable=unused-import, no-name-in-module
 
+import certbot.tests.util as test_util
 
 def get_signals(signums):
     """Get the handlers for an iterable of signums."""
@@ -65,6 +66,8 @@ class ErrorHandlerTest(unittest.TestCase):
         self.init_func.assert_called_once_with(*self.init_args,
                                                **self.init_kwargs)
 
+    # On Windows, this test kills pytest itself !
+    @test_util.broken_on_windows
     def test_context_manager_with_signal(self):
         init_signals = get_signals(self.signals)
         with signal_receiver(self.signals) as signals_received:
@@ -95,6 +98,8 @@ class ErrorHandlerTest(unittest.TestCase):
                                                **self.init_kwargs)
         bad_func.assert_called_once_with()
 
+    # On Windows, this test kills pytest itself !
+    @test_util.broken_on_windows
     def test_bad_recovery_with_signal(self):
         sig1 = self.signals[0]
         sig2 = self.signals[-1]
@@ -144,5 +149,10 @@ class ExitHandlerTest(ErrorHandlerTest):
                                                **self.init_kwargs)
         func.assert_called_once_with()
 
+    # On Windows, this test kills pytest itself !
+    @test_util.broken_on_windows
+    def test_bad_recovery_with_signal(self):
+        super(ExitHandlerTest, self).test_bad_recovery_with_signal()
+
 if __name__ == "__main__":
     unittest.main()  # pragma: no cover
